summaryrefslogtreecommitdiffstats
path: root/remoting/host/client_session.cc
diff options
context:
space:
mode:
Diffstat (limited to 'remoting/host/client_session.cc')
-rw-r--r--remoting/host/client_session.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/remoting/host/client_session.cc b/remoting/host/client_session.cc
index 59c124f..31c3bf1 100644
--- a/remoting/host/client_session.cc
+++ b/remoting/host/client_session.cc
@@ -28,7 +28,7 @@
#include "remoting/protocol/client_stub.h"
#include "remoting/protocol/clipboard_thread_proxy.h"
#include "remoting/protocol/pairing_registry.h"
-#include "third_party/webrtc/modules/desktop_capture/screen_capturer.h"
+#include "third_party/webrtc/modules/desktop_capture/desktop_capturer.h"
// Default DPI to assume for old clients that use notifyClientDimensions.
const int kDefaultDPI = 96;
@@ -453,9 +453,9 @@ void ClientSession::ResetVideoPipeline() {
video_scheduler_ = NULL;
}
- // Create VideoEncoder and ScreenCapturer to match the session's video channel
- // configuration.
- scoped_ptr<webrtc::ScreenCapturer> video_capturer =
+ // Create VideoEncoder and DesktopCapturer to match the session's video
+ // channel configuration.
+ scoped_ptr<webrtc::DesktopCapturer> video_capturer =
extension_manager_->OnCreateVideoCapturer(
desktop_environment_->CreateVideoCapturer());
scoped_ptr<VideoEncoder> video_encoder =